@@ -19,11 +19,11 @@ Template::Flute - Modern designer-friendly HTML templating Engine
 
 =head1 VERSION
 
-Version 0.0130
+Version 0.0131
 
 =cut
 
-our $VERSION = '0.0130';
+our $VERSION = '0.0131';
 
 =head1 SYNOPSIS
 
@@ -915,8 +915,14 @@ sub _replace_record {
             if (my $attribute = $value->{target}) {
                 $elt_handler = sub {
                     my ($elt, $string) = @_;
+                    if (!defined($string)) {
+                        $string = '';
+                    }
                     foreach my $att (_expand_elt_attributes($elt, $attribute)) {
                         my $newtext = $elt->att($att);
+                        if (!defined($newtext)) {
+                            $newtext = '';
+                        }
                         $newtext =~ s/$regexp/$string/;
                         $elt->set_att($att, $newtext)
                     };
@@ -925,7 +931,13 @@ sub _replace_record {
             else {
                 $elt_handler = sub {
                     my ($elt, $string) = @_;
+                    if (!defined($string)) {
+                        $string = '';
+                    }
                     my $newtext = $elt->text;
+                    if (!defined($newtext)) {
+                        $newtext = '';
+                    }
                     $newtext =~ s/$regexp/$string/;
                     $elt->set_text($newtext);
                 };
@@ -1044,9 +1056,22 @@ sub _paging {
 
     my ($iter, $pager);
 
-    if (defined blessed($iterator)
-            && $iterator->can('pager')
-                && ($pager = $iterator->pager)) {
+    if (defined blessed($iterator)) {
+        # DBIx::Class::ResultSet objects have a pager method, but
+        # it throws an error without a limit through the rows attribute
+        if ($iterator->can('pager')) {
+            if ($iterator->can('is_paged')) {
+                if ($iterator->is_paged) {
+                    $pager = $iterator->pager;
+                }
+            }
+            else {
+                $pager = $iterator->pager;
+            }
+        }
+    }
+
+    if ($pager) {
         $iter = Template::Flute::Pager->new(iterator => $pager,
                                             page_size => $page_size);
     }
@@ -2084,6 +2109,9 @@ Template::Flute.
 Thanks to Grega Pompe for proper implementation of nested lists and
 a documentation fix.
 
+Thanks to Jeff Boes for spotting a typo in the documentation of the
+Template::Flute::Filter::JsonVar class.
+
 Thanks to Ton Verhagen for being a big supporter of my projects in all aspects.
 
 Thanks to Sam Batschelet helping me with a bug causing duplicate form fields (GH #14).
